/*
   netrik -- The ANTRIK Internet Viewer
   Copyright (C) Olaf D. Buddenhagen AKA antrik, et al (see AUTHORS)
   Published under the GNU GPL; see LICENSE for details.
*/
/*
 * layout.h -- declarations for layout.c
 *
 * (C) 2001 antrik
 */
#ifndef __LAYOUT_H
#define __LAYOUT_H

#include "items.h"
#include "load.h"
#include "syntax.h"
#include "url.h"

struct Page {    /* all data necessary for loading, layouting and rendering a HTML page */
   struct Resource	*input;    /* input resource descriptor */
   struct Url		*url;    /* effective page URL (NULL means internal page or stdin) */

   struct Element	*syntax_tree;    /* top of syntax parsing tree */
   struct Item		*item_tree;    /* top of structure (item) tree */
   struct Item_list	*page_map;    /* page usage map (one list of items for every line) */
   struct Link_list	*links;    /* list of all links */
   struct Anchor_list	*anchors;    /* list of all anchors */

   int			pager_pos;    /* number of first line currently visible in pager */
   int			active_link;    /* number of currently highlighted link */
   int			active_anchor;    /* nuber of anchor to go to when entering pager; reset after first keypress */

   int			mark;    /* page has return mark */
};

int load_page(const struct Url *base_url, const char *url, const struct Item *form, const struct Page *reference, int page_width, enum Syntax_error *syntax_err);    /* load and layout HTML page */
void free_layout_data(const struct Page *page);    /* unallocate layouting data */
void free_page(struct Page *page);    /* unallocate page data */

#endif
